Modules and Classes
===================


Object Representation
---------------------

:mod:`hgvs.edit`
^^^^^^^^^^^^^^^^

.. automodule:: hgvs.edit

:mod:`hgvs.hgvsposition`
^^^^^^^^^^^^^^^^^^^^^^^^

.. automodule:: hgvs.hgvsposition

:mod:`hgvs.location`
^^^^^^^^^^^^^^^^^^^^

.. automodule:: hgvs.location

:mod:`hgvs.posedit`
^^^^^^^^^^^^^^^^^^^

.. automodule:: hgvs.posedit

:mod:`hgvs.variant`
^^^^^^^^^^^^^^^^^^^

.. automodule:: hgvs.variant



Parsing
-------

:mod:`hgvs.parser`
^^^^^^^^^^^^^^^^^^

.. automodule:: hgvs.parser



Mapping
-------

:mod:`hgvs.variantmapper`
^^^^^^^^^^^^^^^^^^^^^^^^^

.. automodule:: hgvs.variantmapper


:mod:`hgvs.intervalmapper`
^^^^^^^^^^^^^^^^^^^^^^^^^^

.. automodule:: hgvs.intervalmapper


:mod:`hgvs.projector`
^^^^^^^^^^^^^^^^^^^^^

.. automodule:: hgvs.projector

:mod:`hgvs.transcriptmapper`
^^^^^^^^^^^^^^^^^^^^^^^^^^^^

.. automodule:: hgvs.transcriptmapper



Validating
----------

:mod:`hgvs.validator`
^^^^^^^^^^^^^^^^^^^^^

.. automodule:: hgvs.validator



Data Sources
------------

:mod:`hgvs.dataproviders.interface`

.. automodule:: hgvs.dataproviders.interface

:mod:`hgvs.dataproviders.multifastadb`

.. automodule:: hgvs.dataproviders.multifastadb

:mod:`hgvs.dataproviders.uta`

.. automodule:: hgvs.dataproviders.uta
